import asyncio
import json
import re

import arrow
import click
from google.protobuf.json_format import MessageToJson, Parse
from grpc.aio import AioRpcError
from rich.table import Table
from rich.text import Text

from grid.cli import rich_click

# Not sure why we have this import Console
# When I import it normally from rich I have
# import issues
from grid.cli.client import credentials_from_env, Grid
from grid.cli.core.callbacks import arrow_time_callback
from grid.cli.core.formatter import Formatable, print_to_console
from grid.cli.core.logs import cluster_logs, fancy_log_writer
from grid.cli.exceptions import LogLimitExceeded
from grid.protos.grid.v1.cluster_pb2 import (
    AWSClusterDriverSpec,
    Cluster,
    CLUSTER_STATE_RUNNING,
    CLUSTER_TYPE_BYOC,
    ClusterDriver,
    ClusterSpec,
    ClusterState,
    ClusterType,
    InstanceSpec,
    KubernetesClusterDriver,
)
from grid.protos.grid.v1.cluster_service_pb2 import CreateClusterRequest, ListClustersRequest, ListClustersResponse
from grid.protos.grid.v1.cluster_service_pb2_grpc import ClusterServiceStub
from grid.protos.grid.v1.metadata_pb2 import Metadata


class ClusterList(Formatable):
    def __init__(self, clusters: [Cluster]):
        self.clusters = clusters

    def as_json(self) -> str:
        return json.dumps([
            json.loads(MessageToJson(x, including_default_value_fields=True, sort_keys=True)) for x in self.clusters
        ])

    def as_table(self) -> Table:
        table = Table("id", "name", "type", "status", "created", show_header=True, header_style="bold green")
        phases = {
            ClusterState.CLUSTER_STATE_QUEUED: Text("queued", style="bold yellow"),
            ClusterState.CLUSTER_STATE_PENDING: Text("pending", style="bold yellow"),
            ClusterState.CLUSTER_STATE_RUNNING: Text("running", style="bold green"),
            ClusterState.CLUSTER_STATE_FAILED: Text("failed", style="bold red"),
            ClusterState.CLUSTER_STATE_DELETED: Text("deleted", style="bold red"),
        }

        cluster_type_lookup = {
            ClusterType.CLUSTER_TYPE_BYOC: Text("byoc", style="bold yellow"),
            ClusterType.CLUSTER_TYPE_GLOBAL: Text("grid-cloud", style="bold green"),
        }
        for cluster in self.clusters:
            cluster: Cluster
            status = phases[cluster.status.phase]
            if cluster.spec.desired_state == ClusterState.CLUSTER_STATE_DELETED \
                    and cluster.status.phase != ClusterState.CLUSTER_STATE_DELETED:
                status = Text("terminating", style="bold red")
            table.add_row(
                cluster.metadata.id,
                cluster.metadata.name,
                cluster_type_lookup.get(cluster.spec.cluster_type, Text("unknown", style="red")),
                status,
                arrow.get(cluster.metadata.creation_timestamp.ToDatetime()).humanize(),
            )
        return table


@rich_click.group(invoke_without_command=True)
@click.pass_context
def clusters(ctx: click.Context) -> None:
    if ctx.invoked_subcommand is not None:
        return

    async def list_clusters() -> [Cluster]:
        async with Grid.grpc_channel() as conn:
            resp: 'ListClustersResponse' = await ClusterServiceStub(conn).ListClusters(
                ListClustersRequest(
                    cluster_type_not_in=[
                        ClusterType.CLUSTER_TYPE_LEGACY,
                        ClusterType.CLUSTER_TYPE_UNSPECIFIED,
                    ],
                    phase_not_in=[
                        ClusterState.CLUSTER_STATE_DELETED,
                    ]
                )
            )
            return resp.cluster

    try:
        clusters: [Cluster] = asyncio.run(list_clusters())
        print_to_console(ctx, ClusterList(clusters))
    except AioRpcError as e:
        raise click.ClickException(f"cannot list clusters: {e.details()}")


default_instance_types = [
    "g2.8xlarge",
    "g3.16xlarge",
    "g3.4xlarge",
    "g3.8xlarge",
    "g3s.xlarge",
    "g4dn.12xlarge",
    "g4dn.16xlarge",
    "g4dn.2xlarge",
    "g4dn.4xlarge",
    "g4dn.8xlarge",
    "g4dn.metal",
    "g4dn.xlarge",
    "p2.16xlarge",
    "p2.8xlarge",
    "p2.xlarge",
    "p3.16xlarge",
    "p3.2xlarge",
    "p3.8xlarge",
    "p3dn.24xlarge",
    # "p4d.24xlarge",  # currently not supported
    "t2.large",
    "t2.medium",
    "t2.xlarge",
    "t2.2xlarge",
    "t3.large",
    "t3.medium",
    "t3.xlarge",
    "t3.2xlarge",
]


def _check_cluster_name_is_valid(_ctx, _param, value):
    pattern = r"^(?!-)[a-z0-9-]{1,63}(?<!-)$"
    if not re.match(pattern, value):
        raise click.ClickException(
            f"cluster name doesn't match regex pattern {pattern}\nIn simple words, use lowercase letters, numbers, and occasional -"
        )
    return value


@clusters.command()
@click.argument('name', type=str, callback=_check_cluster_name_is_valid)
@click.option('--external-id', 'external_id', type=str, required=True)
@click.option('--role-arn', 'role_arn', type=str, required=True)
@click.option('--region', 'region', type=str, required=False, default="us-east-1")
@click.option('--instance-types', 'instance_types', type=str, required=False, default=",".join(default_instance_types))
@click.option(
    '--edit-before-creation',
    default=False,
    is_flag=True,
    help="edit the created cluster spec before submitting to API server"
)
@click.pass_context
def aws(
    ctx: click.Context,
    name: str,
    external_id: str,
    role_arn: str,
    region: str,
    instance_types: str,
    edit_before_creation: bool,
) -> None:
    creds = credentials_from_env()
    cluster = Cluster(
        metadata=Metadata(
            id=name,
            name=name,
        ),
        spec=ClusterSpec(
            desired_state=CLUSTER_STATE_RUNNING,
            user_id=creds.user_id,
            cluster_type=CLUSTER_TYPE_BYOC,
            driver=ClusterDriver(
                kubernetes=KubernetesClusterDriver(
                    aws=AWSClusterDriverSpec(
                        region=region,
                        role_arn=role_arn,
                        external_id=external_id,
                        instance_types=[InstanceSpec(name=x) for x in instance_types.split(",")]
                    ),
                ),
            )
        )
    )

    if edit_before_creation:
        before = MessageToJson(
            cluster,
            including_default_value_fields=True,
        )
        after = click.edit(before)
        if after is None or after == before:
            click.echo("cluster unchanged")
        else:
            Parse(
                text=after,
                message=cluster,
            )

    async def f():
        async with Grid.grpc_channel() as conn:
            return await ClusterServiceStub(conn).CreateCluster(CreateClusterRequest(cluster=cluster))

    try:
        resp = asyncio.run(f())
        click.echo(MessageToJson(resp.cluster))
    except AioRpcError as e:
        raise click.ClickException(f"cluster {name}: {e.details()}")


# TODO(nmiculinic): refactor this to be under `grid logs`
# Though I don't want to break existing workflows...
@clusters.command()
@click.argument('cluster_id', type=str, callback=_check_cluster_name_is_valid)
@click.option("-t", "--tail", is_flag=True, default=False, help="whether to tail log lines")
@click.option(
    "--from",
    "from_time",
    default="24 hours ago",
    help="from where are the cluster logs queried",
    callback=arrow_time_callback
)
@click.option(
    "--to",
    "to_time",
    default="0 seconds ago",
    callback=arrow_time_callback,
    help="end timestamp/relative for non-tailing requests. It's ignored for tailing ones"
)
@click.option("--limit", default=10000, help="limit the number of log lines returned")
@click.option(
    "--time-format",
    default="human",
    type=click.Choice(['human', 'iso8601'], case_sensitive=False),
    help="limit the number of log lines returned",
)
@click.option(
    "--max-per-query-limit",
    default=1000,
    help=
    "maximum number of items returns per single query. In most usecases this should not be touched, and use --limit instead"
)
def logs(cluster_id: str, time_format: str, **kwargs):
    """fetch cluster logs"""
    async def f():
        async with Grid.grpc_channel() as conn:
            await cluster_logs(
                cluster_id=cluster_id,
                cluster_service=ClusterServiceStub(conn),
                log_writer=fancy_log_writer(
                    time_format=time_format,
                    component="cluster",
                ),
                **kwargs,
            )

    try:
        asyncio.run(f())
    except AioRpcError as e:
        raise click.ClickException(f"cluster {cluster_id}: {e.details()}")
    except LogLimitExceeded:
        raise click.ClickException(
            f"=== more logs present but reached log line limit. Current limit --limit {kwargs['limit']}"
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import tensorboard_service_pb2 as grid_dot_v1_dot_tensorboard__service__pb2


class TensorboardServiceStub(object):
    # missing associated documentation comment in .proto file
    pass

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.CreateTensorboard = channel.unary_unary(
            '/grid.v1.TensorboardService/CreateTensorboard',
            request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.CreateTensorboardRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.CreateTensorboardResponse.FromString,
        )
        self.GetTensorboard = channel.unary_unary(
            '/grid.v1.TensorboardService/GetTensorboard',
            request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.GetTensorboardRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.GetTensorboardResponse.FromString,
        )
        self.ListTensorboards = channel.unary_unary(
            '/grid.v1.TensorboardService/ListTensorboards',
            request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.ListTensorboardsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.ListTensorboardsResponse.FromString,
        )
        self.UpdateTensorboard = channel.unary_unary(
            '/grid.v1.TensorboardService/UpdateTensorboard',
            request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardResponse.FromString,
        )
        self.UpdateTensorboardStatus = channel.unary_unary(
            '/grid.v1.TensorboardService/UpdateTensorboardStatus',
            request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardStatusRequest.
            SerializeToString,
            response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardStatusResponse.FromString,
        )
        self.DeleteTensorboard = channel.unary_unary(
            '/grid.v1.TensorboardService/DeleteTensorboard',
            request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.DeleteTensorboardRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.DeleteTensorboardResponse.FromString,
        )
        self.WatchTensorboards = channel.unary_stream(
            '/grid.v1.TensorboardService/WatchTensorboards',
            request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.WatchTensorboardsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.WatchTensorboardsResponse.FromString,
        )


class TensorboardServiceServicer(object):
    # missing associated documentation comment in .proto file
    pass

    def CreateTensorboard(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTensorboard(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTensorboards(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTensorboard(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTensorboardStatus(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteTensorboard(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchTensorboards(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TensorboardServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'CreateTensorboard':
        grpc.unary_unary_rpc_method_handler(
            servicer.CreateTensorboard,
            request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.CreateTensorboardRequest.FromString,
            response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.CreateTensorboardResponse.SerializeToString,
        ),
        'GetTensorboard':
        grpc.unary_unary_rpc_method_handler(
            servicer.GetTensorboard,
            request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.GetTensorboardRequest.FromString,
            response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.GetTensorboardResponse.SerializeToString,
        ),
        'ListTensorboards':
        grpc.unary_unary_rpc_method_handler(
            servicer.ListTensorboards,
            request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.ListTensorboardsRequest.FromString,
            response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.ListTensorboardsResponse.SerializeToString,
        ),
        'UpdateTensorboard':
        grpc.unary_unary_rpc_method_handler(
            servicer.UpdateTensorboard,
            request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardRequest.FromString,
            response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardResponse.SerializeToString,
        ),
        'UpdateTensorboardStatus':
        grpc.unary_unary_rpc_method_handler(
            servicer.UpdateTensorboardStatus,
            request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardStatusRequest.FromString,
            response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardStatusResponse.
            SerializeToString,
        ),
        'DeleteTensorboard':
        grpc.unary_unary_rpc_method_handler(
            servicer.DeleteTensorboard,
            request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.DeleteTensorboardRequest.FromString,
            response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.DeleteTensorboardResponse.SerializeToString,
        ),
        'WatchTensorboards':
        grpc.unary_stream_rpc_method_handler(
            servicer.WatchTensorboards,
            request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.WatchTensorboardsRequest.FromString,
            response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.WatchTensorboardsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler('grid.v1.TensorboardService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler, ))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/session_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2

from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from grid.protos.grid.v1 import session_pb2 as grid_dot_v1_dot_session__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/session_service.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x1dgrid/v1/session_service.proto\x12\x07grid.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16grid/v1/metadata.proto\x1a\x15grid/v1/session.proto\"B\n\x14\x43reateSessionRequest\x12*\n\x07session\x18\x01 \x01(\x0b\x32\x10.grid.v1.SessionR\x07session\"C\n\x15\x43reateSessionResponse\x12*\n\x07session\x18\x01 \x01(\x0b\x32\x10.grid.v1.SessionR\x07session\"#\n\x11GetSessionRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"@\n\x12GetSessionResponse\x12*\n\x07session\x18\x01 \x01(\x0b\x32\x10.grid.v1.SessionR\x07session\"\xa0\x02\n\x13ListSessionsRequest\x12%\n\x0e\x63ontinue_token\x18\x01 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x03 \x01(\x03R\x05limit\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\x12\x1d\n\ncluster_id\x18\x05 \x01(\tR\tclusterId\x12\x30\n\x08phase_in\x18\x06 \x03(\x0e\x32\x15.grid.v1.SessionStateR\x07phaseIn\x12\x37\n\x0cphase_not_in\x18\x07 \x03(\x0e\x32\x15.grid.v1.SessionStateR\nphaseNotIn\"\x94\x01\n\x14ListSessionsResponse\x12*\n\x07session\x18\x01 \x03(\x0b\x32\x10.grid.v1.SessionR\x07session\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x03 \x01(\tR\x0fresourceVersion\"B\n\x14UpdateSessionRequest\x12*\n\x07session\x18\x01 \x01(\x0b\x32\x10.grid.v1.SessionR\x07session\"C\n\x15UpdateSessionResponse\x12*\n\x07session\x18\x01 \x01(\x0b\x32\x10.grid.v1.SessionR\x07session\"H\n\x1aUpdateSessionStatusRequest\x12*\n\x07session\x18\x01 \x01(\x0b\x32\x10.grid.v1.SessionR\x07session\"I\n\x1bUpdateSessionStatusResponse\x12*\n\x07session\x18\x01 \x01(\x0b\x32\x10.grid.v1.SessionR\x07session\"B\n\x14\x44\x65leteSessionRequest\x12*\n\x07session\x18\x01 \x01(\x0b\x32\x10.grid.v1.SessionR\x07session\"C\n\x15\x44\x65leteSessionResponse\x12*\n\x07session\x18\x01 \x01(\x0b\x32\x10.grid.v1.SessionR\x07session\"\xfa\x01\n\x14WatchSessionsRequest\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\x12\x1d\n\ncluster_id\x18\x05 \x01(\tR\tclusterId\x12\x30\n\x08phase_in\x18\x06 \x03(\x0e\x32\x15.grid.v1.SessionStateR\x07phaseIn\x12\x37\n\x0cphase_not_in\x18\x07 \x03(\x0e\x32\x15.grid.v1.SessionStateR\nphaseNotIn\"\x9b\x01\n\x15WatchSessionsResponse\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x17.grid.v1.WatchEventTypeR\x04type\x12*\n\x07session\x18\x03 \x01(\x0b\x32\x10.grid.v1.SessionR\x07session2\xd2\x04\n\x0eSessionService\x12P\n\rCreateSession\x12\x1d.grid.v1.CreateSessionRequest\x1a\x1e.grid.v1.CreateSessionResponse\"\x00\x12G\n\nGetSession\x12\x1a.grid.v1.GetSessionRequest\x1a\x1b.grid.v1.GetSessionResponse\"\x00\x12M\n\x0cListSessions\x12\x1c.grid.v1.ListSessionsRequest\x1a\x1d.grid.v1.ListSessionsResponse\"\x00\x12P\n\rUpdateSession\x12\x1d.grid.v1.UpdateSessionRequest\x1a\x1e.grid.v1.UpdateSessionResponse\"\x00\x12`\n\x13UpdateSessionStatus\x12#.grid.v1.UpdateSessionStatusRequest\x1a$.grid.v1.UpdateSessionStatusResponse\x12P\n\rDeleteSession\x12\x1d.grid.v1.DeleteSessionRequest\x1a\x1e.grid.v1.DeleteSessionResponse\"\x00\x12P\n\rWatchSessions\x12\x1d.grid.v1.WatchSessionsRequest\x1a\x1e.grid.v1.WatchSessionsResponse0\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
        grid_dot_v1_dot_session__pb2.DESCRIPTOR,
    ]
)

_CREATESESSIONREQUEST = _descriptor.Descriptor(
    name='CreateSessionRequest',
    full_name='grid.v1.CreateSessionRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='session',
            full_name='grid.v1.CreateSessionRequest.session',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='session',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=119,
    serialized_end=185,
)

_CREATESESSIONRESPONSE = _descriptor.Descriptor(
    name='CreateSessionResponse',
    full_name='grid.v1.CreateSessionResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='session',
            full_name='grid.v1.CreateSessionResponse.session',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='session',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=187,
    serialized_end=254,
)

_GETSESSIONREQUEST = _descriptor.Descriptor(
    name='GetSessionRequest',
    full_name='grid.v1.GetSessionRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='id',
            full_name='grid.v1.GetSessionRequest.id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='id',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=256,
    serialized_end=291,
)

_GETSESSIONRESPONSE = _descriptor.Descriptor(
    name='GetSessionResponse',
    full_name='grid.v1.GetSessionResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='session',
            full_name='grid.v1.GetSessionResponse.session',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='session',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=293,
    serialized_end=357,
)

_LISTSESSIONSREQUEST = _descriptor.Descriptor(
    name='ListSessionsRequest',
    full_name='grid.v1.ListSessionsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListSessionsRequest.continue_token',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.ListSessionsRequest.resource_version',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.ListSessionsRequest.limit',
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.ListSessionsRequest.user_id',
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.ListSessionsRequest.cluster_id',
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_in',
            full_name='grid.v1.ListSessionsRequest.phase_in',
            index=5,
            number=6,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_not_in',
            full_name='grid.v1.ListSessionsRequest.phase_not_in',
            index=6,
            number=7,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseNotIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=360,
    serialized_end=648,
)

_LISTSESSIONSRESPONSE = _descriptor.Descriptor(
    name='ListSessionsResponse',
    full_name='grid.v1.ListSessionsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='session',
            full_name='grid.v1.ListSessionsResponse.session',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='session',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListSessionsResponse.continue_token',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.ListSessionsResponse.resource_version',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=651,
    serialized_end=799,
)

_UPDATESESSIONREQUEST = _descriptor.Descriptor(
    name='UpdateSessionRequest',
    full_name='grid.v1.UpdateSessionRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='session',
            full_name='grid.v1.UpdateSessionRequest.session',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='session',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=801,
    serialized_end=867,
)

_UPDATESESSIONRESPONSE = _descriptor.Descriptor(
    name='UpdateSessionResponse',
    full_name='grid.v1.UpdateSessionResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='session',
            full_name='grid.v1.UpdateSessionResponse.session',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='session',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=869,
    serialized_end=936,
)

_UPDATESESSIONSTATUSREQUEST = _descriptor.Descriptor(
    name='UpdateSessionStatusRequest',
    full_name='grid.v1.UpdateSessionStatusRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='session',
            full_name='grid.v1.UpdateSessionStatusRequest.session',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='session',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=938,
    serialized_end=1010,
)

_UPDATESESSIONSTATUSRESPONSE = _descriptor.Descriptor(
    name='UpdateSessionStatusResponse',
    full_name='grid.v1.UpdateSessionStatusResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='session',
            full_name='grid.v1.UpdateSessionStatusResponse.session',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='session',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1012,
    serialized_end=1085,
)

_DELETESESSIONREQUEST = _descriptor.Descriptor(
    name='DeleteSessionRequest',
    full_name='grid.v1.DeleteSessionRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='session',
            full_name='grid.v1.DeleteSessionRequest.session',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='session',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1087,
    serialized_end=1153,
)

_DELETESESSIONRESPONSE = _descriptor.Descriptor(
    name='DeleteSessionResponse',
    full_name='grid.v1.DeleteSessionResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='session',
            full_name='grid.v1.DeleteSessionResponse.session',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='session',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1155,
    serialized_end=1222,
)

_WATCHSESSIONSREQUEST = _descriptor.Descriptor(
    name='WatchSessionsRequest',
    full_name='grid.v1.WatchSessionsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.WatchSessionsRequest.resource_version',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.WatchSessionsRequest.limit',
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.WatchSessionsRequest.user_id',
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.WatchSessionsRequest.cluster_id',
            index=3,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_in',
            full_name='grid.v1.WatchSessionsRequest.phase_in',
            index=4,
            number=6,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_not_in',
            full_name='grid.v1.WatchSessionsRequest.phase_not_in',
            index=5,
            number=7,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseNotIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1225,
    serialized_end=1475,
)

_WATCHSESSIONSRESPONSE = _descriptor.Descriptor(
    name='WatchSessionsResponse',
    full_name='grid.v1.WatchSessionsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.WatchSessionsResponse.resource_version',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='type',
            full_name='grid.v1.WatchSessionsResponse.type',
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='type',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='session',
            full_name='grid.v1.WatchSessionsResponse.session',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='session',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1478,
    serialized_end=1633,
)

_CREATESESSIONREQUEST.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
_CREATESESSIONRESPONSE.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
_GETSESSIONRESPONSE.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
_LISTSESSIONSREQUEST.fields_by_name['phase_in'].enum_type = grid_dot_v1_dot_session__pb2._SESSIONSTATE
_LISTSESSIONSREQUEST.fields_by_name['phase_not_in'].enum_type = grid_dot_v1_dot_session__pb2._SESSIONSTATE
_LISTSESSIONSRESPONSE.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
_UPDATESESSIONREQUEST.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
_UPDATESESSIONRESPONSE.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
_UPDATESESSIONSTATUSREQUEST.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
_UPDATESESSIONSTATUSRESPONSE.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
_DELETESESSIONREQUEST.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
_DELETESESSIONRESPONSE.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
_WATCHSESSIONSREQUEST.fields_by_name['phase_in'].enum_type = grid_dot_v1_dot_session__pb2._SESSIONSTATE
_WATCHSESSIONSREQUEST.fields_by_name['phase_not_in'].enum_type = grid_dot_v1_dot_session__pb2._SESSIONSTATE
_WATCHSESSIONSRESPONSE.fields_by_name['type'].enum_type = grid_dot_v1_dot_metadata__pb2._WATCHEVENTTYPE
_WATCHSESSIONSRESPONSE.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
DESCRIPTOR.message_types_by_name['CreateSessionRequest'] = _CREATESESSIONREQUEST
DESCRIPTOR.message_types_by_name['CreateSessionResponse'] = _CREATESESSIONRESPONSE
DESCRIPTOR.message_types_by_name['GetSessionRequest'] = _GETSESSIONREQUEST
DESCRIPTOR.message_types_by_name['GetSessionResponse'] = _GETSESSIONRESPONSE
DESCRIPTOR.message_types_by_name['ListSessionsRequest'] = _LISTSESSIONSREQUEST
DESCRIPTOR.message_types_by_name['ListSessionsResponse'] = _LISTSESSIONSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateSessionRequest'] = _UPDATESESSIONREQUEST
DESCRIPTOR.message_types_by_name['UpdateSessionResponse'] = _UPDATESESSIONRESPONSE
DESCRIPTOR.message_types_by_name['UpdateSessionStatusRequest'] = _UPDATESESSIONSTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateSessionStatusResponse'] = _UPDATESESSIONSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteSessionRequest'] = _DELETESESSIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteSessionResponse'] = _DELETESESSIONRESPONSE
DESCRIPTOR.message_types_by_name['WatchSessionsRequest'] = _WATCHSESSIONSREQUEST
DESCRIPTOR.message_types_by_name['WatchSessionsResponse'] = _WATCHSESSIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateSessionRequest = _reflection.GeneratedProtocolMessageType(
    'CreateSessionRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CREATESESSIONREQUEST,
        '__module__': 'grid.v1.session_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CreateSessionRequest)
    }
)
_sym_db.RegisterMessage(CreateSessionRequest)

CreateSessionResponse = _reflection.GeneratedProtocolMessageType(
    'CreateSessionResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CREATESESSIONRESPONSE,
        '__module__': 'grid.v1.session_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CreateSessionResponse)
    }
)
_sym_db.RegisterMessage(CreateSessionResponse)

GetSessionRequest = _reflection.GeneratedProtocolMessageType(
    'GetSessionRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETSESSIONREQUEST,
        '__module__': 'grid.v1.session_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetSessionRequest)
    }
)
_sym_db.RegisterMessage(GetSessionRequest)

GetSessionResponse = _reflection.GeneratedProtocolMessageType(
    'GetSessionResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETSESSIONRESPONSE,
        '__module__': 'grid.v1.session_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetSessionResponse)
    }
)
_sym_db.RegisterMessage(GetSessionResponse)

ListSessionsRequest = _reflection.GeneratedProtocolMessageType(
    'ListSessionsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTSESSIONSREQUEST,
        '__module__': 'grid.v1.session_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListSessionsRequest)
    }
)
_sym_db.RegisterMessage(ListSessionsRequest)

ListSessionsResponse = _reflection.GeneratedProtocolMessageType(
    'ListSessionsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTSESSIONSRESPONSE,
        '__module__': 'grid.v1.session_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListSessionsResponse)
    }
)
_sym_db.RegisterMessage(ListSessionsResponse)

UpdateSessionRequest = _reflection.GeneratedProtocolMessageType(
    'UpdateSessionRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATESESSIONREQUEST,
        '__module__': 'grid.v1.session_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateSessionRequest)
    }
)
_sym_db.RegisterMessage(UpdateSessionRequest)

UpdateSessionResponse = _reflection.GeneratedProtocolMessageType(
    'UpdateSessionResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATESESSIONRESPONSE,
        '__module__': 'grid.v1.session_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateSessionResponse)
    }
)
_sym_db.RegisterMessage(UpdateSessionResponse)

UpdateSessionStatusRequest = _reflection.GeneratedProtocolMessageType(
    'UpdateSessionStatusRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATESESSIONSTATUSREQUEST,
        '__module__': 'grid.v1.session_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateSessionStatusRequest)
    }
)
_sym_db.RegisterMessage(UpdateSessionStatusRequest)

UpdateSessionStatusResponse = _reflection.GeneratedProtocolMessageType(
    'UpdateSessionStatusResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATESESSIONSTATUSRESPONSE,
        '__module__': 'grid.v1.session_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateSessionStatusResponse)
    }
)
_sym_db.RegisterMessage(UpdateSessionStatusResponse)

DeleteSessionRequest = _reflection.GeneratedProtocolMessageType(
    'DeleteSessionRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DELETESESSIONREQUEST,
        '__module__': 'grid.v1.session_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DeleteSessionRequest)
    }
)
_sym_db.RegisterMessage(DeleteSessionRequest)

DeleteSessionResponse = _reflection.GeneratedProtocolMessageType(
    'DeleteSessionResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DELETESESSIONRESPONSE,
        '__module__': 'grid.v1.session_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DeleteSessionResponse)
    }
)
_sym_db.RegisterMessage(DeleteSessionResponse)

WatchSessionsRequest = _reflection.GeneratedProtocolMessageType(
    'WatchSessionsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHSESSIONSREQUEST,
        '__module__': 'grid.v1.session_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchSessionsRequest)
    }
)
_sym_db.RegisterMessage(WatchSessionsRequest)

WatchSessionsResponse = _reflection.GeneratedProtocolMessageType(
    'WatchSessionsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHSESSIONSRESPONSE,
        '__module__': 'grid.v1.session_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchSessionsResponse)
    }
)
_sym_db.RegisterMessage(WatchSessionsResponse)

DESCRIPTOR._options = None

_SESSIONSERVICE = _descriptor.ServiceDescriptor(
    name='SessionService',
    full_name='grid.v1.SessionService',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=1636,
    serialized_end=2230,
    methods=[
        _descriptor.MethodDescriptor(
            name='CreateSession',
            full_name='grid.v1.SessionService.CreateSession',
            index=0,
            containing_service=None,
            input_type=_CREATESESSIONREQUEST,
            output_type=_CREATESESSIONRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='GetSession',
            full_name='grid.v1.SessionService.GetSession',
            index=1,
            containing_service=None,
            input_type=_GETSESSIONREQUEST,
            output_type=_GETSESSIONRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='ListSessions',
            full_name='grid.v1.SessionService.ListSessions',
            index=2,
            containing_service=None,
            input_type=_LISTSESSIONSREQUEST,
            output_type=_LISTSESSIONSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='UpdateSession',
            full_name='grid.v1.SessionService.UpdateSession',
            index=3,
            containing_service=None,
            input_type=_UPDATESESSIONREQUEST,
            output_type=_UPDATESESSIONRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='UpdateSessionStatus',
            full_name='grid.v1.SessionService.UpdateSessionStatus',
            index=4,
            containing_service=None,
            input_type=_UPDATESESSIONSTATUSREQUEST,
            output_type=_UPDATESESSIONSTATUSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='DeleteSession',
            full_name='grid.v1.SessionService.DeleteSession',
            index=5,
            containing_service=None,
            input_type=_DELETESESSIONREQUEST,
            output_type=_DELETESESSIONRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='WatchSessions',
            full_name='grid.v1.SessionService.WatchSessions',
            index=6,
            containing_service=None,
            input_type=_WATCHSESSIONSREQUEST,
            output_type=_WATCHSESSIONSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ]
)
_sym_db.RegisterServiceDescriptor(_SESSIONSERVICE)

DESCRIPTOR.services_by_name['SessionService'] = _SESSIONSERVICE

# @@protoc_insertion_point(module_scope)



# coding: utf-8
"""
    external/v1/external_session_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from grid.openapi.configuration import Configuration


class V1AzureClusterDriverSpec(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'instance_types': 'list[V1InstanceSpec]',
        'internal_test_cluster': 'bool',
        'kubernetes_version': 'str',
        'region': 'str',
        'subscription_id': 'str'
    }

    attribute_map = {
        'instance_types': 'instanceTypes',
        'internal_test_cluster': 'internalTestCluster',
        'kubernetes_version': 'kubernetesVersion',
        'region': 'region',
        'subscription_id': 'subscriptionId'
    }

    def __init__(
        self,
        instance_types=None,
        internal_test_cluster=None,
        kubernetes_version=None,
        region=None,
        subscription_id=None,
        _configuration=None
    ):  # noqa: E501
        """V1AzureClusterDriverSpec - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._instance_types = None
        self._internal_test_cluster = None
        self._kubernetes_version = None
        self._region = None
        self._subscription_id = None
        self.discriminator = None

        if instance_types is not None:
            self.instance_types = instance_types
        if internal_test_cluster is not None:
            self.internal_test_cluster = internal_test_cluster
        if kubernetes_version is not None:
            self.kubernetes_version = kubernetes_version
        if region is not None:
            self.region = region
        if subscription_id is not None:
            self.subscription_id = subscription_id

    @property
    def instance_types(self):
        """Gets the instance_types of this V1AzureClusterDriverSpec.  # noqa: E501


        :return: The instance_types of this V1AzureClusterDriverSpec.  # noqa: E501
        :rtype: list[V1InstanceSpec]
        """
        return self._instance_types

    @instance_types.setter
    def instance_types(self, instance_types):
        """Sets the instance_types of this V1AzureClusterDriverSpec.


        :param instance_types: The instance_types of this V1AzureClusterDriverSpec.  # noqa: E501
        :type: list[V1InstanceSpec]
        """

        self._instance_types = instance_types

    @property
    def internal_test_cluster(self):
        """Gets the internal_test_cluster of this V1AzureClusterDriverSpec.  # noqa: E501


        :return: The internal_test_cluster of this V1AzureClusterDriverSpec.  # noqa: E501
        :rtype: bool
        """
        return self._internal_test_cluster

    @internal_test_cluster.setter
    def internal_test_cluster(self, internal_test_cluster):
        """Sets the internal_test_cluster of this V1AzureClusterDriverSpec.


        :param internal_test_cluster: The internal_test_cluster of this V1AzureClusterDriverSpec.  # noqa: E501
        :type: bool
        """

        self._internal_test_cluster = internal_test_cluster

    @property
    def kubernetes_version(self):
        """Gets the kubernetes_version of this V1AzureClusterDriverSpec.  # noqa: E501


        :return: The kubernetes_version of this V1AzureClusterDriverSpec.  # noqa: E501
        :rtype: str
        """
        return self._kubernetes_version

    @kubernetes_version.setter
    def kubernetes_version(self, kubernetes_version):
        """Sets the kubernetes_version of this V1AzureClusterDriverSpec.


        :param kubernetes_version: The kubernetes_version of this V1AzureClusterDriverSpec.  # noqa: E501
        :type: str
        """

        self._kubernetes_version = kubernetes_version

    @property
    def region(self):
        """Gets the region of this V1AzureClusterDriverSpec.  # noqa: E501


        :return: The region of this V1AzureClusterDriverSpec.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this V1AzureClusterDriverSpec.


        :param region: The region of this V1AzureClusterDriverSpec.  # noqa: E501
        :type: str
        """

        self._region = region

    @property
    def subscription_id(self):
        """Gets the subscription_id of this V1AzureClusterDriverSpec.  # noqa: E501


        :return: The subscription_id of this V1AzureClusterDriverSpec.  # noqa: E501
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """Sets the subscription_id of this V1AzureClusterDriverSpec.


        :param subscription_id: The subscription_id of this V1AzureClusterDriverSpec.  # noqa: E501
        :type: str
        """

        self._subscription_id = subscription_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict") else item, value.items()
                    )
                )
            else:
                result[attr] = value
        if issubclass(V1AzureClusterDriverSpec, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1AzureClusterDriverSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1AzureClusterDriverSpec):
            return True

        return self.to_dict() != other.to_dict()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from grid.protos.grid.v1 import cluster_pb2 as grid_dot_v1_dot_cluster__pb2
from grid.protos.grid.v1 import logs_pb2 as grid_dot_v1_dot_logs__pb2
from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/cluster_service.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x1dgrid/v1/cluster_service.proto\x12\x07grid.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16grid/v1/metadata.proto\x1a\x15grid/v1/cluster.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x12grid/v1/logs.proto\"B\n\x14\x43reateClusterRequest\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"C\n\x15\x43reateClusterResponse\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"#\n\x11GetClusterRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"@\n\x12GetClusterResponse\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"\x8d\x04\n\x13ListClustersRequest\x12%\n\x0e\x63ontinue_token\x18\x01 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x03 \x01(\x03R\x05limit\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\x12\x30\n\x08phase_in\x18\x05 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\x07phaseIn\x12\x37\n\x0cphase_not_in\x18\x06 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\nphaseNotIn\x12?\n\x10\x64\x65sired_state_in\x18\x07 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\x0e\x64\x65siredStateIn\x12\x46\n\x14\x64\x65sired_state_not_in\x18\x08 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\x11\x64\x65siredStateNotIn\x12<\n\x0f\x63luster_type_in\x18\t \x03(\x0e\x32\x14.grid.v1.ClusterTypeR\rclusterTypeIn\x12\x43\n\x13\x63luster_type_not_in\x18\n \x03(\x0e\x32\x14.grid.v1.ClusterTypeR\x10\x63lusterTypeNotIn\"\x94\x01\n\x14ListClustersResponse\x12*\n\x07\x63luster\x18\x01 \x03(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x03 \x01(\tR\x0fresourceVersion\"B\n\x14UpdateClusterRequest\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"C\n\x15UpdateClusterResponse\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"H\n\x1aUpdateClusterStatusRequest\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"I\n\x1bUpdateClusterStatusResponse\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"B\n\x14\x44\x65leteClusterRequest\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"C\n\x15\x44\x65leteClusterResponse\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"\xe7\x03\n\x14WatchClustersRequest\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\x12\x30\n\x08phase_in\x18\x05 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\x07phaseIn\x12\x37\n\x0cphase_not_in\x18\x06 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\nphaseNotIn\x12?\n\x10\x64\x65sired_state_in\x18\x07 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\x0e\x64\x65siredStateIn\x12\x46\n\x14\x64\x65sired_state_not_in\x18\x08 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\x11\x64\x65siredStateNotIn\x12<\n\x0f\x63luster_type_in\x18\t \x03(\x0e\x32\x14.grid.v1.ClusterTypeR\rclusterTypeIn\x12\x43\n\x13\x63luster_type_not_in\x18\n \x03(\x0e\x32\x14.grid.v1.ClusterTypeR\x10\x63lusterTypeNotIn\"\x9b\x01\n\x15WatchClustersResponse\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x17.grid.v1.WatchEventTypeR\x04type\x12*\n\x07\x63luster\x18\x03 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"\xd4\x01\n\x17QueryClusterLogsRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x14\n\x05limit\x18\x02 \x01(\x04R\x05limit\x12\x43\n\x0fstart_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0estartTimestamp\x12?\n\rend_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0c\x65ndTimestamp\"G\n\x18QueryClusterLogsResponse\x12+\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x11.grid.v1.LogEntryR\x07\x65ntries\"\x92\x01\n\x16TailClusterLogsRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x14\n\x05limit\x18\x02 \x01(\x04R\x05limit\x12\x43\n\x0fstart_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0estartTimestamp\"F\n\x17TailClusterLogsResponse\x12+\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x11.grid.v1.LogEntryR\x07\x65ntries2\x83\x06\n\x0e\x43lusterService\x12P\n\rCreateCluster\x12\x1d.grid.v1.CreateClusterRequest\x1a\x1e.grid.v1.CreateClusterResponse\"\x00\x12G\n\nGetCluster\x12\x1a.grid.v1.GetClusterRequest\x1a\x1b.grid.v1.GetClusterResponse\"\x00\x12M\n\x0cListClusters\x12\x1c.grid.v1.ListClustersRequest\x1a\x1d.grid.v1.ListClustersResponse\"\x00\x12P\n\rUpdateCluster\x12\x1d.grid.v1.UpdateClusterRequest\x1a\x1e.grid.v1.UpdateClusterResponse\"\x00\x12`\n\x13UpdateClusterStatus\x12#.grid.v1.UpdateClusterStatusRequest\x1a$.grid.v1.UpdateClusterStatusResponse\x12P\n\rDeleteCluster\x12\x1d.grid.v1.DeleteClusterRequest\x1a\x1e.grid.v1.DeleteClusterResponse\"\x00\x12P\n\rWatchClusters\x12\x1d.grid.v1.WatchClustersRequest\x1a\x1e.grid.v1.WatchClustersResponse0\x01\x12W\n\x10QueryClusterLogs\x12 .grid.v1.QueryClusterLogsRequest\x1a!.grid.v1.QueryClusterLogsResponse\x12V\n\x0fTailClusterLogs\x12\x1f.grid.v1.TailClusterLogsRequest\x1a .grid.v1.TailClusterLogsResponse0\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
        grid_dot_v1_dot_cluster__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        grid_dot_v1_dot_logs__pb2.DESCRIPTOR,
    ]
)

_CREATECLUSTERREQUEST = _descriptor.Descriptor(
    name='CreateClusterRequest',
    full_name='grid.v1.CreateClusterRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.CreateClusterRequest.cluster',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=172,
    serialized_end=238,
)

_CREATECLUSTERRESPONSE = _descriptor.Descriptor(
    name='CreateClusterResponse',
    full_name='grid.v1.CreateClusterResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.CreateClusterResponse.cluster',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=240,
    serialized_end=307,
)

_GETCLUSTERREQUEST = _descriptor.Descriptor(
    name='GetClusterRequest',
    full_name='grid.v1.GetClusterRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='id',
            full_name='grid.v1.GetClusterRequest.id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='id',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=309,
    serialized_end=344,
)

_GETCLUSTERRESPONSE = _descriptor.Descriptor(
    name='GetClusterResponse',
    full_name='grid.v1.GetClusterResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.GetClusterResponse.cluster',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=346,
    serialized_end=410,
)

_LISTCLUSTERSREQUEST = _descriptor.Descriptor(
    name='ListClustersRequest',
    full_name='grid.v1.ListClustersRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListClustersRequest.continue_token',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.ListClustersRequest.resource_version',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.ListClustersRequest.limit',
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.ListClustersRequest.user_id',
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_in',
            full_name='grid.v1.ListClustersRequest.phase_in',
            index=4,
            number=5,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_not_in',
            full_name='grid.v1.ListClustersRequest.phase_not_in',
            index=5,
            number=6,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseNotIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='desired_state_in',
            full_name='grid.v1.ListClustersRequest.desired_state_in',
            index=6,
            number=7,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='desiredStateIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='desired_state_not_in',
            full_name='grid.v1.ListClustersRequest.desired_state_not_in',
            index=7,
            number=8,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='desiredStateNotIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_type_in',
            full_name='grid.v1.ListClustersRequest.cluster_type_in',
            index=8,
            number=9,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterTypeIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_type_not_in',
            full_name='grid.v1.ListClustersRequest.cluster_type_not_in',
            index=9,
            number=10,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterTypeNotIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=413,
    serialized_end=938,
)

_LISTCLUSTERSRESPONSE = _descriptor.Descriptor(
    name='ListClustersResponse',
    full_name='grid.v1.ListClustersResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.ListClustersResponse.cluster',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListClustersResponse.continue_token',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.ListClustersResponse.resource_version',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=941,
    serialized_end=1089,
)

_UPDATECLUSTERREQUEST = _descriptor.Descriptor(
    name='UpdateClusterRequest',
    full_name='grid.v1.UpdateClusterRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.UpdateClusterRequest.cluster',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1091,
    serialized_end=1157,
)

_UPDATECLUSTERRESPONSE = _descriptor.Descriptor(
    name='UpdateClusterResponse',
    full_name='grid.v1.UpdateClusterResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.UpdateClusterResponse.cluster',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1159,
    serialized_end=1226,
)

_UPDATECLUSTERSTATUSREQUEST = _descriptor.Descriptor(
    name='UpdateClusterStatusRequest',
    full_name='grid.v1.UpdateClusterStatusRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.UpdateClusterStatusRequest.cluster',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1228,
    serialized_end=1300,
)

_UPDATECLUSTERSTATUSRESPONSE = _descriptor.Descriptor(
    name='UpdateClusterStatusResponse',
    full_name='grid.v1.UpdateClusterStatusResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.UpdateClusterStatusResponse.cluster',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1302,
    serialized_end=1375,
)

_DELETECLUSTERREQUEST = _descriptor.Descriptor(
    name='DeleteClusterRequest',
    full_name='grid.v1.DeleteClusterRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.DeleteClusterRequest.cluster',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1377,
    serialized_end=1443,
)

_DELETECLUSTERRESPONSE = _descriptor.Descriptor(
    name='DeleteClusterResponse',
    full_name='grid.v1.DeleteClusterResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.DeleteClusterResponse.cluster',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1445,
    serialized_end=1512,
)

_WATCHCLUSTERSREQUEST = _descriptor.Descriptor(
    name='WatchClustersRequest',
    full_name='grid.v1.WatchClustersRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.WatchClustersRequest.resource_version',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.WatchClustersRequest.limit',
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.WatchClustersRequest.user_id',
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_in',
            full_name='grid.v1.WatchClustersRequest.phase_in',
            index=3,
            number=5,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase_not_in',
            full_name='grid.v1.WatchClustersRequest.phase_not_in',
            index=4,
            number=6,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phaseNotIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='desired_state_in',
            full_name='grid.v1.WatchClustersRequest.desired_state_in',
            index=5,
            number=7,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='desiredStateIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='desired_state_not_in',
            full_name='grid.v1.WatchClustersRequest.desired_state_not_in',
            index=6,
            number=8,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='desiredStateNotIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_type_in',
            full_name='grid.v1.WatchClustersRequest.cluster_type_in',
            index=7,
            number=9,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterTypeIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_type_not_in',
            full_name='grid.v1.WatchClustersRequest.cluster_type_not_in',
            index=8,
            number=10,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterTypeNotIn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1515,
    serialized_end=2002,
)

_WATCHCLUSTERSRESPONSE = _descriptor.Descriptor(
    name='WatchClustersResponse',
    full_name='grid.v1.WatchClustersResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.WatchClustersResponse.resource_version',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='type',
            full_name='grid.v1.WatchClustersResponse.type',
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='type',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster',
            full_name='grid.v1.WatchClustersResponse.cluster',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=2005,
    serialized_end=2160,
)

_QUERYCLUSTERLOGSREQUEST = _descriptor.Descriptor(
    name='QueryClusterLogsRequest',
    full_name='grid.v1.QueryClusterLogsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.QueryClusterLogsRequest.cluster_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.QueryClusterLogsRequest.limit',
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='start_timestamp',
            full_name='grid.v1.QueryClusterLogsRequest.start_timestamp',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='startTimestamp',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='end_timestamp',
            full_name='grid.v1.QueryClusterLogsRequest.end_timestamp',
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='endTimestamp',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=2163,
    serialized_end=2375,
)

_QUERYCLUSTERLOGSRESPONSE = _descriptor.Descriptor(
    name='QueryClusterLogsResponse',
    full_name='grid.v1.QueryClusterLogsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='entries',
            full_name='grid.v1.QueryClusterLogsResponse.entries',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='entries',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=2377,
    serialized_end=2448,
)

_TAILCLUSTERLOGSREQUEST = _descriptor.Descriptor(
    name='TailClusterLogsRequest',
    full_name='grid.v1.TailClusterLogsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.TailClusterLogsRequest.cluster_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.TailClusterLogsRequest.limit',
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='start_timestamp',
            full_name='grid.v1.TailClusterLogsRequest.start_timestamp',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='startTimestamp',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=2451,
    serialized_end=2597,
)

_TAILCLUSTERLOGSRESPONSE = _descriptor.Descriptor(
    name='TailClusterLogsResponse',
    full_name='grid.v1.TailClusterLogsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='entries',
            full_name='grid.v1.TailClusterLogsResponse.entries',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='entries',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=2599,
    serialized_end=2669,
)

_CREATECLUSTERREQUEST.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_CREATECLUSTERRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_GETCLUSTERRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_LISTCLUSTERSREQUEST.fields_by_name['phase_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_LISTCLUSTERSREQUEST.fields_by_name['phase_not_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_LISTCLUSTERSREQUEST.fields_by_name['desired_state_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_LISTCLUSTERSREQUEST.fields_by_name['desired_state_not_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_LISTCLUSTERSREQUEST.fields_by_name['cluster_type_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERTYPE
_LISTCLUSTERSREQUEST.fields_by_name['cluster_type_not_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERTYPE
_LISTCLUSTERSRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_UPDATECLUSTERREQUEST.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_UPDATECLUSTERRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_UPDATECLUSTERSTATUSREQUEST.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_UPDATECLUSTERSTATUSRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_DELETECLUSTERREQUEST.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_DELETECLUSTERRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_WATCHCLUSTERSREQUEST.fields_by_name['phase_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_WATCHCLUSTERSREQUEST.fields_by_name['phase_not_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_WATCHCLUSTERSREQUEST.fields_by_name['desired_state_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_WATCHCLUSTERSREQUEST.fields_by_name['desired_state_not_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_WATCHCLUSTERSREQUEST.fields_by_name['cluster_type_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERTYPE
_WATCHCLUSTERSREQUEST.fields_by_name['cluster_type_not_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERTYPE
_WATCHCLUSTERSRESPONSE.fields_by_name['type'].enum_type = grid_dot_v1_dot_metadata__pb2._WATCHEVENTTYPE
_WATCHCLUSTERSRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_QUERYCLUSTERLOGSREQUEST.fields_by_name['start_timestamp'
                                        ].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUERYCLUSTERLOGSREQUEST.fields_by_name['end_timestamp'
                                        ].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUERYCLUSTERLOGSRESPONSE.fields_by_name['entries'].message_type = grid_dot_v1_dot_logs__pb2._LOGENTRY
_TAILCLUSTERLOGSREQUEST.fields_by_name['start_timestamp'
                                       ].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TAILCLUSTERLOGSRESPONSE.fields_by_name['entries'].message_type = grid_dot_v1_dot_logs__pb2._LOGENTRY
DESCRIPTOR.message_types_by_name['CreateClusterRequest'] = _CREATECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['CreateClusterResponse'] = _CREATECLUSTERRESPONSE
DESCRIPTOR.message_types_by_name['GetClusterRequest'] = _GETCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['GetClusterResponse'] = _GETCLUSTERRESPONSE
DESCRIPTOR.message_types_by_name['ListClustersRequest'] = _LISTCLUSTERSREQUEST
DESCRIPTOR.message_types_by_name['ListClustersResponse'] = _LISTCLUSTERSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateClusterRequest'] = _UPDATECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['UpdateClusterResponse'] = _UPDATECLUSTERRESPONSE
DESCRIPTOR.message_types_by_name['UpdateClusterStatusRequest'] = _UPDATECLUSTERSTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateClusterStatusResponse'] = _UPDATECLUSTERSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteClusterRequest'] = _DELETECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['DeleteClusterResponse'] = _DELETECLUSTERRESPONSE
DESCRIPTOR.message_types_by_name['WatchClustersRequest'] = _WATCHCLUSTERSREQUEST
DESCRIPTOR.message_types_by_name['WatchClustersResponse'] = _WATCHCLUSTERSRESPONSE
DESCRIPTOR.message_types_by_name['QueryClusterLogsRequest'] = _QUERYCLUSTERLOGSREQUEST
DESCRIPTOR.message_types_by_name['QueryClusterLogsResponse'] = _QUERYCLUSTERLOGSRESPONSE
DESCRIPTOR.message_types_by_name['TailClusterLogsRequest'] = _TAILCLUSTERLOGSREQUEST
DESCRIPTOR.message_types_by_name['TailClusterLogsResponse'] = _TAILCLUSTERLOGSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateClusterRequest = _reflection.GeneratedProtocolMessageType(
    'CreateClusterRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CREATECLUSTERREQUEST,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CreateClusterRequest)
    }
)
_sym_db.RegisterMessage(CreateClusterRequest)

CreateClusterResponse = _reflection.GeneratedProtocolMessageType(
    'CreateClusterResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CREATECLUSTERRESPONSE,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CreateClusterResponse)
    }
)
_sym_db.RegisterMessage(CreateClusterResponse)

GetClusterRequest = _reflection.GeneratedProtocolMessageType(
    'GetClusterRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETCLUSTERREQUEST,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetClusterRequest)
    }
)
_sym_db.RegisterMessage(GetClusterRequest)

GetClusterResponse = _reflection.GeneratedProtocolMessageType(
    'GetClusterResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETCLUSTERRESPONSE,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetClusterResponse)
    }
)
_sym_db.RegisterMessage(GetClusterResponse)

ListClustersRequest = _reflection.GeneratedProtocolMessageType(
    'ListClustersRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTCLUSTERSREQUEST,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListClustersRequest)
    }
)
_sym_db.RegisterMessage(ListClustersRequest)

ListClustersResponse = _reflection.GeneratedProtocolMessageType(
    'ListClustersResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTCLUSTERSRESPONSE,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListClustersResponse)
    }
)
_sym_db.RegisterMessage(ListClustersResponse)

UpdateClusterRequest = _reflection.GeneratedProtocolMessageType(
    'UpdateClusterRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATECLUSTERREQUEST,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateClusterRequest)
    }
)
_sym_db.RegisterMessage(UpdateClusterRequest)

UpdateClusterResponse = _reflection.GeneratedProtocolMessageType(
    'UpdateClusterResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATECLUSTERRESPONSE,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateClusterResponse)
    }
)
_sym_db.RegisterMessage(UpdateClusterResponse)

UpdateClusterStatusRequest = _reflection.GeneratedProtocolMessageType(
    'UpdateClusterStatusRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATECLUSTERSTATUSREQUEST,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateClusterStatusRequest)
    }
)
_sym_db.RegisterMessage(UpdateClusterStatusRequest)

UpdateClusterStatusResponse = _reflection.GeneratedProtocolMessageType(
    'UpdateClusterStatusResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATECLUSTERSTATUSRESPONSE,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateClusterStatusResponse)
    }
)
_sym_db.RegisterMessage(UpdateClusterStatusResponse)

DeleteClusterRequest = _reflection.GeneratedProtocolMessageType(
    'DeleteClusterRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DELETECLUSTERREQUEST,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DeleteClusterRequest)
    }
)
_sym_db.RegisterMessage(DeleteClusterRequest)

DeleteClusterResponse = _reflection.GeneratedProtocolMessageType(
    'DeleteClusterResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DELETECLUSTERRESPONSE,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DeleteClusterResponse)
    }
)
_sym_db.RegisterMessage(DeleteClusterResponse)

WatchClustersRequest = _reflection.GeneratedProtocolMessageType(
    'WatchClustersRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHCLUSTERSREQUEST,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchClustersRequest)
    }
)
_sym_db.RegisterMessage(WatchClustersRequest)

WatchClustersResponse = _reflection.GeneratedProtocolMessageType(
    'WatchClustersResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHCLUSTERSRESPONSE,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchClustersResponse)
    }
)
_sym_db.RegisterMessage(WatchClustersResponse)

QueryClusterLogsRequest = _reflection.GeneratedProtocolMessageType(
    'QueryClusterLogsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _QUERYCLUSTERLOGSREQUEST,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.QueryClusterLogsRequest)
    }
)
_sym_db.RegisterMessage(QueryClusterLogsRequest)

QueryClusterLogsResponse = _reflection.GeneratedProtocolMessageType(
    'QueryClusterLogsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _QUERYCLUSTERLOGSRESPONSE,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.QueryClusterLogsResponse)
    }
)
_sym_db.RegisterMessage(QueryClusterLogsResponse)

TailClusterLogsRequest = _reflection.GeneratedProtocolMessageType(
    'TailClusterLogsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _TAILCLUSTERLOGSREQUEST,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.TailClusterLogsRequest)
    }
)
_sym_db.RegisterMessage(TailClusterLogsRequest)

TailClusterLogsResponse = _reflection.GeneratedProtocolMessageType(
    'TailClusterLogsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _TAILCLUSTERLOGSRESPONSE,
        '__module__': 'grid.v1.cluster_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.TailClusterLogsResponse)
    }
)
_sym_db.RegisterMessage(TailClusterLogsResponse)

DESCRIPTOR._options = None

_CLUSTERSERVICE = _descriptor.ServiceDescriptor(
    name='ClusterService',
    full_name='grid.v1.ClusterService',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=2672,
    serialized_end=3443,
    methods=[
        _descriptor.MethodDescriptor(
            name='CreateCluster',
            full_name='grid.v1.ClusterService.CreateCluster',
            index=0,
            containing_service=None,
            input_type=_CREATECLUSTERREQUEST,
            output_type=_CREATECLUSTERRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='GetCluster',
            full_name='grid.v1.ClusterService.GetCluster',
            index=1,
            containing_service=None,
            input_type=_GETCLUSTERREQUEST,
            output_type=_GETCLUSTERRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='ListClusters',
            full_name='grid.v1.ClusterService.ListClusters',
            index=2,
            containing_service=None,
            input_type=_LISTCLUSTERSREQUEST,
            output_type=_LISTCLUSTERSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='UpdateCluster',
            full_name='grid.v1.ClusterService.UpdateCluster',
            index=3,
            containing_service=None,
            input_type=_UPDATECLUSTERREQUEST,
            output_type=_UPDATECLUSTERRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='UpdateClusterStatus',
            full_name='grid.v1.ClusterService.UpdateClusterStatus',
            index=4,
            containing_service=None,
            input_type=_UPDATECLUSTERSTATUSREQUEST,
            output_type=_UPDATECLUSTERSTATUSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='DeleteCluster',
            full_name='grid.v1.ClusterService.DeleteCluster',
            index=5,
            containing_service=None,
            input_type=_DELETECLUSTERREQUEST,
            output_type=_DELETECLUSTERRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='WatchClusters',
            full_name='grid.v1.ClusterService.WatchClusters',
            index=6,
            containing_service=None,
            input_type=_WATCHCLUSTERSREQUEST,
            output_type=_WATCHCLUSTERSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='QueryClusterLogs',
            full_name='grid.v1.ClusterService.QueryClusterLogs',
            index=7,
            containing_service=None,
            input_type=_QUERYCLUSTERLOGSREQUEST,
            output_type=_QUERYCLUSTERLOGSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='TailClusterLogs',
            full_name='grid.v1.ClusterService.TailClusterLogs',
            index=8,
            containing_service=None,
            input_type=_TAILCLUSTERLOGSREQUEST,
            output_type=_TAILCLUSTERLOGSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ]
)
_sym_db.RegisterServiceDescriptor(_CLUSTERSERVICE)

DESCRIPTOR.services_by_name['ClusterService'] = _CLUSTERSERVICE

# @@protoc_insertion_point(module_scope)



import asyncio

import click
from grpc.aio import AioRpcError

from grid.cli import rich_click
from grid.cli.client import credentials_from_env, Grid
from grid.cli.core.team import Team
from grid.protos.grid.v1.user_pb2 import *
from grid.protos.grid.v1.user_service_pb2 import *
from grid.protos.grid.v1.user_service_pb2_grpc import *


@rich_click.group(invoke_without_command=True)
@click.pass_context
def user(ctx):
    """Show your information."""
    if ctx.invoked_subcommand is not None:
        return

    client = Grid()

    user_info = client.get_user_info()

    email = user_info['email']
    email = email if email is not None else "N/A"

    click.echo(f"Display name: {user_info['firstName']} {user_info['lastName']}")
    click.echo(f"Username    : {user_info['username']}")
    click.echo(f"Email       : {email}")

    teams = Team.get_all()
    if teams:
        click.echo("Teams:\n-")
        for t in teams:
            click.echo(f"  {t.name} - Role: {t.role}")


@user.command()
@click.argument('cluster_id', type=str)
def set_default_cluster(cluster_id: str):
    creds = credentials_from_env()

    async def f():
        async with Grid.grpc_channel() as conn:
            stub = UserServiceStub(conn)
            resp: 'GetUserResponse' = await stub.GetUser(GetUserRequest(id=creds.user_id, ))
            user: 'User' = resp.user
            user.MergeFrom(User(details=UserDetails(preferences=UserPreferences(default_cluster_id=cluster_id, ))))
            await stub.UpdateUser(UpdateUserRequest(user=user, ))

    try:
        asyncio.run(f())
        click.echo(f"default cluster_id set to {cluster_id}")
    except AioRpcError as e:
        raise click.ClickException(f"cannot set default cluster: {e.details()}")



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import suspicious_activity_pb2 as grid_dot_v1_dot_suspicious__activity__pb2


class SuspiciousActivityServiceStub(object):
    # missing associated documentation comment in .proto file
    pass

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.ReportSuspiciousActivity = channel.unary_unary(
            '/grid.v1.SuspiciousActivityService/ReportSuspiciousActivity',
            request_serializer=grid_dot_v1_dot_suspicious__activity__pb2.ReportSuspiciousActivityRequest.
            SerializeToString,
            response_deserializer=grid_dot_v1_dot_suspicious__activity__pb2.ReportSuspiciousActivityResponse.FromString,
        )


class SuspiciousActivityServiceServicer(object):
    # missing associated documentation comment in .proto file
    pass

    def ReportSuspiciousActivity(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SuspiciousActivityServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'ReportSuspiciousActivity':
        grpc.unary_unary_rpc_method_handler(
            servicer.ReportSuspiciousActivity,
            request_deserializer=grid_dot_v1_dot_suspicious__activity__pb2.ReportSuspiciousActivityRequest.FromString,
            response_serializer=grid_dot_v1_dot_suspicious__activity__pb2.ReportSuspiciousActivityResponse.
            SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler('grid.v1.SuspiciousActivityService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler, ))



# coding: utf-8
"""
    external/v1/external_session_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from grid.openapi.configuration import Configuration


class V1KubernetesClusterStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'azure': 'V1AzureClusterDriverStatus',
        'bastion_host_ip': 'str',
        'eks': 'V1EKSCusterDriverStatus',
        'ingress_ca_cert': 'str',
        'ingress_load_balancer_hostname': 'str',
        'ingress_load_balancer_ip': 'str',
        'ssh_gateway_hostname': 'str',
        'ssh_private_key': 'str',
        'ssh_public_key': 'str'
    }

    attribute_map = {
        'azure': 'azure',
        'bastion_host_ip': 'bastionHostIp',
        'eks': 'eks',
        'ingress_ca_cert': 'ingressCaCert',
        'ingress_load_balancer_hostname': 'ingressLoadBalancerHostname',
        'ingress_load_balancer_ip': 'ingressLoadBalancerIp',
        'ssh_gateway_hostname': 'sshGatewayHostname',
        'ssh_private_key': 'sshPrivateKey',
        'ssh_public_key': 'sshPublicKey'
    }

    def __init__(
        self,
        azure=None,
        bastion_host_ip=None,
        eks=None,
        ingress_ca_cert=None,
        ingress_load_balancer_hostname=None,
        ingress_load_balancer_ip=None,
        ssh_gateway_hostname=None,
        ssh_private_key=None,
        ssh_public_key=None,
        _configuration=None
    ):  # noqa: E501
        """V1KubernetesClusterStatus - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._azure = None
        self._bastion_host_ip = None
        self._eks = None
        self._ingress_ca_cert = None
        self._ingress_load_balancer_hostname = None
        self._ingress_load_balancer_ip = None
        self._ssh_gateway_hostname = None
        self._ssh_private_key = None
        self._ssh_public_key = None
        self.discriminator = None

        if azure is not None:
            self.azure = azure
        if bastion_host_ip is not None:
            self.bastion_host_ip = bastion_host_ip
        if eks is not None:
            self.eks = eks
        if ingress_ca_cert is not None:
            self.ingress_ca_cert = ingress_ca_cert
        if ingress_load_balancer_hostname is not None:
            self.ingress_load_balancer_hostname = ingress_load_balancer_hostname
        if ingress_load_balancer_ip is not None:
            self.ingress_load_balancer_ip = ingress_load_balancer_ip
        if ssh_gateway_hostname is not None:
            self.ssh_gateway_hostname = ssh_gateway_hostname
        if ssh_private_key is not None:
            self.ssh_private_key = ssh_private_key
        if ssh_public_key is not None:
            self.ssh_public_key = ssh_public_key

    @property
    def azure(self):
        """Gets the azure of this V1KubernetesClusterStatus.  # noqa: E501


        :return: The azure of this V1KubernetesClusterStatus.  # noqa: E501
        :rtype: V1AzureClusterDriverStatus
        """
        return self._azure

    @azure.setter
    def azure(self, azure):
        """Sets the azure of this V1KubernetesClusterStatus.


        :param azure: The azure of this V1KubernetesClusterStatus.  # noqa: E501
        :type: V1AzureClusterDriverStatus
        """

        self._azure = azure

    @property
    def bastion_host_ip(self):
        """Gets the bastion_host_ip of this V1KubernetesClusterStatus.  # noqa: E501


        :return: The bastion_host_ip of this V1KubernetesClusterStatus.  # noqa: E501
        :rtype: str
        """
        return self._bastion_host_ip

    @bastion_host_ip.setter
    def bastion_host_ip(self, bastion_host_ip):
        """Sets the bastion_host_ip of this V1KubernetesClusterStatus.


        :param bastion_host_ip: The bastion_host_ip of this V1KubernetesClusterStatus.  # noqa: E501
        :type: str
        """

        self._bastion_host_ip = bastion_host_ip

    @property
    def eks(self):
        """Gets the eks of this V1KubernetesClusterStatus.  # noqa: E501


        :return: The eks of this V1KubernetesClusterStatus.  # noqa: E501
        :rtype: V1EKSCusterDriverStatus
        """
        return self._eks

    @eks.setter
    def eks(self, eks):
        """Sets the eks of this V1KubernetesClusterStatus.


        :param eks: The eks of this V1KubernetesClusterStatus.  # noqa: E501
        :type: V1EKSCusterDriverStatus
        """

        self._eks = eks

    @property
    def ingress_ca_cert(self):
        """Gets the ingress_ca_cert of this V1KubernetesClusterStatus.  # noqa: E501


        :return: The ingress_ca_cert of this V1KubernetesClusterStatus.  # noqa: E501
        :rtype: str
        """
        return self._ingress_ca_cert

    @ingress_ca_cert.setter
    def ingress_ca_cert(self, ingress_ca_cert):
        """Sets the ingress_ca_cert of this V1KubernetesClusterStatus.


        :param ingress_ca_cert: The ingress_ca_cert of this V1KubernetesClusterStatus.  # noqa: E501
        :type: str
        """
        if (
            self._configuration.client_side_validation and ingress_ca_cert is not None
            and not re.search(r'^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', ingress_ca_cert)
        ):  # noqa: E501
            raise ValueError(
                r"Invalid value for `ingress_ca_cert`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`"
            )  # noqa: E501

        self._ingress_ca_cert = ingress_ca_cert

    @property
    def ingress_load_balancer_hostname(self):
        """Gets the ingress_load_balancer_hostname of this V1KubernetesClusterStatus.  # noqa: E501


        :return: The ingress_load_balancer_hostname of this V1KubernetesClusterStatus.  # noqa: E501
        :rtype: str
        """
        return self._ingress_load_balancer_hostname

    @ingress_load_balancer_hostname.setter
    def ingress_load_balancer_hostname(self, ingress_load_balancer_hostname):
        """Sets the ingress_load_balancer_hostname of this V1KubernetesClusterStatus.


        :param ingress_load_balancer_hostname: The ingress_load_balancer_hostname of this V1KubernetesClusterStatus.  # noqa: E501
        :type: str
        """

        self._ingress_load_balancer_hostname = ingress_load_balancer_hostname

    @property
    def ingress_load_balancer_ip(self):
        """Gets the ingress_load_balancer_ip of this V1KubernetesClusterStatus.  # noqa: E501


        :return: The ingress_load_balancer_ip of this V1KubernetesClusterStatus.  # noqa: E501
        :rtype: str
        """
        return self._ingress_load_balancer_ip

    @ingress_load_balancer_ip.setter
    def ingress_load_balancer_ip(self, ingress_load_balancer_ip):
        """Sets the ingress_load_balancer_ip of this V1KubernetesClusterStatus.


        :param ingress_load_balancer_ip: The ingress_load_balancer_ip of this V1KubernetesClusterStatus.  # noqa: E501
        :type: str
        """

        self._ingress_load_balancer_ip = ingress_load_balancer_ip

    @property
    def ssh_gateway_hostname(self):
        """Gets the ssh_gateway_hostname of this V1KubernetesClusterStatus.  # noqa: E501


        :return: The ssh_gateway_hostname of this V1KubernetesClusterStatus.  # noqa: E501
        :rtype: str
        """
        return self._ssh_gateway_hostname

    @ssh_gateway_hostname.setter
    def ssh_gateway_hostname(self, ssh_gateway_hostname):
        """Sets the ssh_gateway_hostname of this V1KubernetesClusterStatus.


        :param ssh_gateway_hostname: The ssh_gateway_hostname of this V1KubernetesClusterStatus.  # noqa: E501
        :type: str
        """

        self._ssh_gateway_hostname = ssh_gateway_hostname

    @property
    def ssh_private_key(self):
        """Gets the ssh_private_key of this V1KubernetesClusterStatus.  # noqa: E501


        :return: The ssh_private_key of this V1KubernetesClusterStatus.  # noqa: E501
        :rtype: str
        """
        return self._ssh_private_key

    @ssh_private_key.setter
    def ssh_private_key(self, ssh_private_key):
        """Sets the ssh_private_key of this V1KubernetesClusterStatus.


        :param ssh_private_key: The ssh_private_key of this V1KubernetesClusterStatus.  # noqa: E501
        :type: str
        """

        self._ssh_private_key = ssh_private_key

    @property
    def ssh_public_key(self):
        """Gets the ssh_public_key of this V1KubernetesClusterStatus.  # noqa: E501


        :return: The ssh_public_key of this V1KubernetesClusterStatus.  # noqa: E501
        :rtype: str
        """
        return self._ssh_public_key

    @ssh_public_key.setter
    def ssh_public_key(self, ssh_public_key):
        """Sets the ssh_public_key of this V1KubernetesClusterStatus.


        :param ssh_public_key: The ssh_public_key of this V1KubernetesClusterStatus.  # noqa: E501
        :type: str
        """

        self._ssh_public_key = ssh_public_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict") else item, value.items()
                    )
                )
            else:
                result[attr] = value
        if issubclass(V1KubernetesClusterStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1KubernetesClusterStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1KubernetesClusterStatus):
            return True

        return self.to_dict() != other.to_dict()
